import Vue from 'vue';
import VueRouter from 'vue-router';
import store from '@/store/index';
import { Notification } from 'element-ui';

Vue.use(VueRouter);

const newPlan = [
  {
    path: '/newPlan/index',
    name: 'newPlan_list',
    meta: { title: '新计划', sub: '管理' },
    component: () => import('@/views/new-plan/index.vue'),
  },
  {
    path: '/newPlan/detail',
    name: 'newPlan_arrange',
    meta: { title: '计划安排' },
    component: () => import('@/views/new-plan/detail.vue'),
  },
  {
    path: '/newPlan/student',
    name: 'newPlan_student',
    meta: { title: '上传学生名单' },
    component: () => import('@/views/new-plan/student.vue'),
  },
];

const routes = [
  {
    path: '/',
    name: 'frame',
    component: () => import('@/views/index.vue'),
    children: [
      ...newPlan,
      {
        path: '/',
        name: 'home',
        component: () => import('@/views/home.vue'),
      },
      {
        path: '/plan/index',
        name: 'plan_list',
        meta: { title: '计划', sub: '管理' },
        component: () => import('@/views/plan/index.vue'),
      },
      {
        path: '/plan/detail',
        name: 'plan_detail',
        meta: { title: '计划', sub: '详情' },
        component: () => import('@/views/plan/detail.vue'),
      },
      {
        path: '/teacher/index',
        name: 'teacher_list',
        meta: { title: '教师', sub: '管理' },
        component: () => import('@/views/teacher/index.vue'),
      },
      //考勤
      {
        path: '/kaoqin/index',
        name: 'kaoqin_list',
        meta: { title: '考勤', sub: '管理' },
        component: () => import('@/views/kaoqin/index.vue'),
      },

      {
        path: '/scganli/index',
        name: 'teacher_list',
        meta: { title: '学生', sub: '管理' },
        component: () => import('@/views/scganli/index.vue'),
      },
      {
        path: '/scganli/detail',
        name: 'teacher_list',
        meta: { title: '上传学生', sub: '详情' },
        component: () => import('@/views/scganli/detail.vue'),
      },
      {
        path: '/teacher/detail',
        name: 'teacher_detail',
        meta: { title: '教师', sub: '信息' },
        component: () => import('@/views/teacher/detail.vue'),
      },
      {
        path: '/leave/index',
        name: 'leave_list',
        meta: { title: '请假', sub: '管理' },
        component: () => import('@/views/leave/index.vue'),
      },
      {
        path: '/stud/detail',
        name: 'stud_detail',
        meta: { title: '学生', sub: '信息' },
        component: () => import('@/views/leave/stud.vue'),
      },
      {
        path: '/student/index',
        name: 'student_index',
        meta: { title: '学生', sub: '管理' },
        component: () => import('@/views/student/index.vue'),
      },
      {
        path: '/student/detail',
        name: 'student_detail',
        meta: { title: '学生', sub: '详情' },
        component: () => import('@/views/student/detail.vue'),
      },
      {
        path: '/school/info',
        name: 'school_info',
        meta: { title: '学校', sub: '资料' },
        component: () => import('@/views/info/index.vue'),
      },
      // 08-23
      // 培训学生管理
      {
        path: '/trainStudent/index',
        name: 'trainStudent_index',
        meta: { title: '培训学生', sub: '管理' },
        component: () => import('@/views/trainStudent/index.vue'),
      },
    ],
  },
  {
    path: '/login',
    name: 'login',
    meta: { title: '登录', sub: '管理' },
    component: () => import('@/views/register/login.vue'),
  },
];

const router = new VueRouter({
  mode: 'history',
  base: process.env.NODE_ENV === 'development' ? '' : 'school',
  routes,
});
router.beforeEach((to, form, next) => {
  store.commit('setUser');
  store.dispatch('setting/checkCache');
  if (to.name === 'login') {
    next();
    return;
  }
  let user = store.state.user;
  if (user) {
    if (to.path === '/school/info') {
      next();
    } else {
      if (user.type == process.env.VUE_APP_USER_TYPE) {
        console.log('缓存登陆');
        let { status } = user;
        if (status === '0') next('/school/info');
        else next();
      } else {
        Notification({
          title: '请重新登陆',
          message: `原因:非当前端用户,需要重新登陆`,
          type: 'warning',
        });
        console.error('非当前端用户,需要重新登陆');
        next({ name: 'login' });
      }
    }
  }
  //下面是没登录的情况,需要跳转页面到用户未登录页
  else next({ name: 'login' });
});
export default router;
